==> order-center-infrastructure-2.0.9-CLOUD-TEST-20220619.223126-242-sources.jar: com/tydic/dyc/oc/repository/po/UocApplyOrderItemPo.java <==
package com.tydic.dyc.oc.repository.po;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocApplyOrderItemPo
 * 说明:申请明细
 * 时间:2022-04-01 17:35
 * 作者:罗有
 **/
@Data
public class UocApplyOrderItemPo implements Serializable {
	private static final long serialVersionUID = 8491906940825816308L;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "申请明细id")
	private Long applyOrderItemId;

	@DocField(value = "申请单id")
	private Long applyOrderId;

	@DocField(value = "明细类型")
	private Integer itemType;

	@DocField(value = "明细编码")
	private String itemCode;

	@DocField(value = "单品ID")
	private String skuId;

	@DocField(value = "单品名称")
	private String skuName;

	@DocField(value = "商品类型ID")
	private String commodityTypeId;

	@DocField(value = "商品类型名称")
	private String commodityTypeName;

	@DocField(value = "供应商名称")
	private String supplierName;

	@DocField(value = "供应商ID")
	private String supplierId;

	@DocField(value = "店铺ID")
	private String supplierShopId;

	@DocField(value = "店铺名称")
	private String supplierShopName;

	@DocField(value = "物料ID")
	private String materialId;

	@DocField(value = "物料名称")
	private String materialName;

	@DocField(value = "扩展字段")
	private String extField1;

	@DocField(value = "扩展字段")
	private String extField2;

	@DocField(value = "扩展字段")
	private String extField3;

	@DocField(value = "扩展字段")
	private String extField4;

	@DocField(value = "扩展字段")
	private String extField5;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建时间 开始")
	private Date createTimeStart;

	@DocField(value = "创建时间 结束")
	private Date createTimeEnd;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新时间 开始")
	private Date updateTimeStart;

	@DocField(value = "更新时间 结束")
	private Date updateTimeEnd;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "备注")
	private String remark;

	@DocField(value = "删除标志1已删除")
	private Integer delTag;

	@DocField(value = "排序")
	private String orderBy;

}

==> order-center-infrastructure-3.1.0-CLOUD-TEST-20230731.024100-76-sources.jar: com/tydic/dyc/oc/repository/po/UocApplyOrderItemPo.java <==
package com.tydic.dyc.oc.repository.po;


import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.util.Date;

/**
 * 标题:UocApplyOrderItemPo
 * 说明:申请明细
 * 时间:2022-04-01 17:35
 * 作者:罗有
 **/
@Data
@EqualsAndHashCode(callSuper=false)
public class UocApplyOrderItemPo implements Serializable {
	private static final long serialVersionUID = 8491906940825816308L;

	//订单id")
	private Long orderId;

	//申请明细id")
	private Long applyOrderItemId;

	//申请单id")
	private Long applyOrderId;

	//明细类型")
	private Integer itemType;

	//明细编码")
	private String itemCode;

	//单品ID")
	private String skuId;

	//单品名称")
	private String skuName;

	//商品类型ID")
	private String commodityTypeId;

	//商品类型名称")
	private String commodityTypeName;

	//供应商名称")
	private String supplierName;

	//供应商ID")
	private String supplierId;

	//店铺ID")
	private String supplierShopId;

	//店铺名称")
	private String supplierShopName;

	//物料ID")
	private String materialId;

	//物料名称")
	private String materialName;

	//扩展字段")
	private String extField1;

	//扩展字段")
	private String extField2;

	//扩展字段")
	private String extField3;

	//扩展字段")
	private String extField4;

	//扩展字段")
	private String extField5;

	//创建时间")
	private Date createTime;

	//创建时间 开始")
	private Date createTimeStart;

	//创建时间 结束")
	private Date createTimeEnd;

	//创建工号")
	private String createOperId;

	//更新时间")
	private Date updateTime;

	//更新时间 开始")
	private Date updateTimeStart;

	//更新时间 结束")
	private Date updateTimeEnd;

	//更新工号")
	private String updateOperId;

	//备注")
	private String remark;

	//删除标志1已删除")
	private Integer delTag;

	//排序")
	private String orderBy;

}
